package exampleSetWidgets;
import java.awt.*;
import javax.swing.*;

import java.awt.event.*;

/**
 * <code>DemoBasic_v3</code> is similar to <code>DemoBasic_v2</code>: it
 * has two components, a <code>JLabel</code> and a <code>JButton</code>
 * (whereas v2 had only a <code>JLabel</code>). We add a listener to the
 * <code>JButton</code>, so that we can implement user interaction. The
 * listener that we add is an instance of <code>MyListener</code>, a class
 * that implements <code>ActionListener</code>.
 * <p>
 * Screen snapshot<br>
 * <center><img src = "img/DemoBasic_v3-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoBasic_v3.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoBasicV3 {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new DemoBasicFrameV3();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle(frame.getClass().getName());
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}

}

class DemoBasicFrameV3 extends JFrame {
	JLabel sampleLabel;
	JButton toggleButton;

	public DemoBasicFrameV3() {
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		// Step 1: Create and Configure Components
		sampleLabel = new JLabel("Sample Label");
		sampleLabel.setPreferredSize(new Dimension(250, 100));
		sampleLabel.setFont(new Font("sanserif", Font.PLAIN, 16));

		toggleButton = new JButton("Press me!");
		toggleButton.setFont(new Font("sanserif", Font.PLAIN, 16));

		// Step 2: Register Listeners
		toggleButton.addActionListener(new MyListener());

		// Step 3: Arrange components in contentPane
		JPanel panel = new JPanel();
		panel.add(sampleLabel);
		panel.add(toggleButton);
		setContentPane(panel);
	}

	public boolean isLowerCase(String s) {
		return s.equals(s.toLowerCase());
	}

	// This is an _inner_ class
	private class MyListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			// if (ae.getSource() == toggleButton) {
			System.out.println("toggleButton generated ActionEvent");
			if (isLowerCase(sampleLabel.getText()))
				sampleLabel.setText(sampleLabel.getText().toUpperCase());
			else
				sampleLabel.setText(sampleLabel.getText().toLowerCase());
			// }
		}
	} // end of class MyListener

} // end of class DemoBasicFrame
