package exampleSetWidgets;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * Program to demonstrate disabling buttons.
 * <p>
 * 
 * <p>
 * Screen snapshot<br>
 * <center><img src = "img/DemoDisabledButton-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoDisabledButton.java">source code</a>
 * @author Scott MacKenzie, 2002
 */
public class DemoDisabledButton {
	public static void main(String[] args) {
		DemoDisabledButtonFrame frame = new DemoDisabledButtonFrame();
		frame.setTitle("DemoDisabledButton");
		frame.pack();
		frame.show();
	}
}

class DemoDisabledButtonFrame extends JFrame implements ActionListener {
	final int INITIAL_COUNT = 5;
	final int MIN_COUNT = 0;
	final int MAX_COUNT = 9;

	private int count;
	private JTextField countField;
	private JButton decrementButton;
	private JButton incrementButton;
	private JButton exitButton;

	// constructor

	public DemoDisabledButtonFrame() {
		count = INITIAL_COUNT;

		// -------------------------------
		// create and configure components
		// -------------------------------

		countField = new JTextField("" + count);
		countField.setFont(new Font("Serif", Font.BOLD, 28));
		countField.setForeground(Color.blue);
		countField.setBackground(Color.pink);
		countField.setHorizontalAlignment(SwingConstants.CENTER);

		ImageIcon decIcon = new ImageIcon("decrementIcon.gif");

		ImageIcon incIcon = new ImageIcon("incrementIcon.gif");

		decrementButton = new JButton(decIcon);
		incrementButton = new JButton(incIcon);

		ImageIcon decIconDisabled = new ImageIcon("decrementIcon-disabled.gif");
		ImageIcon incIconDisabled = new ImageIcon("incrementIcon-disabled.gif");

		decrementButton.setDisabledIcon(decIconDisabled);
		incrementButton.setDisabledIcon(incIconDisabled);

		exitButton = new JButton("Exit");

		// -------------
		// add listeners
		// -------------

		decrementButton.addActionListener(this);
		incrementButton.addActionListener(this);
		exitButton.addActionListener(this);
		this.addWindowListener(new WindowCloser());

		// ------------------
		// arrange components
		// ------------------

		// put components in panels

		JPanel topPanel = new JPanel();
		topPanel.setLayout(new GridLayout(1, 2));
		topPanel.add(decrementButton);
		topPanel.add(incrementButton);

		JPanel bottomPanel = new JPanel();
		bottomPanel.setBorder(BorderFactory.createEmptyBorder(50, 30, 50, 30));
		bottomPanel.setLayout(new GridLayout(3, 1));
		bottomPanel.add(topPanel);
		bottomPanel.add(countField);
		bottomPanel.add(exitButton);

		// create a container for this (extended) JFrame's content pane

		Container contentPane = this.getContentPane();

		// add panels to the container

		contentPane.add(bottomPanel, "Center");
	}

	// -------------------------------
	// implement ActionListener method
	// -------------------------------

	public void actionPerformed(ActionEvent ae) {
		if (ae.getSource() == decrementButton) {
			count--;
			countField.setText("" + count);
			switch (count) {
			case MIN_COUNT:
				decrementButton.setEnabled(false);
				break;
			case (MAX_COUNT - 1):
				incrementButton.setEnabled(true);
				break;
			}
		} else if (ae.getSource() == incrementButton) {
			count++;
			countField.setText("" + count);
			switch (count) {
			case (MIN_COUNT + 1):
				decrementButton.setEnabled(true);
				break;
			case MAX_COUNT:
				incrementButton.setEnabled(false);
				break;
			}
		}

		else if (ae.getSource() == exitButton)
			System.exit(0);
	}

	// Note: WindowAdapter implements WindowListener

	private class WindowCloser extends WindowAdapter {
		public void windowClosing(WindowEvent event) {
			System.exit(0);
		}
	}
}
