package exampleSetWidgets;
import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.border.*;

/**
 * Program to demonstrate using a variety of Swing's built-in message boxes.
 * <p>
 * 
 * <b>Source code notes:</b><br>
 * 
 * The error message box also beeps. This is accomplished by adding the
 * following line of code:
 * <p>
 * 
 * <pre>
 * Toolkit.getDefaultToolkit().beep();
 * </pre>
 * 
 * @see <a href="DemoMessageBox.java">source code</a>
 * @author Scott MacKenzie, 2002, [MB: renamed app, made actionlistener an inner class]
 */
public class DemoMessageBoxSeuss {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new DemoMessageBoxFrame2();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.setTitle(frame.getClass().getName());
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}
}

class DemoMessageBoxFrame2 extends JFrame {
	private JButton plain;
	private JButton information;
	private JButton error;
	private JButton warning;
	private JButton question;

	// constructor
	public DemoMessageBoxFrame2() {
		// -------------------------------
		// create and configure components
		// -------------------------------

		plain = new JButton("Plain");
		information = new JButton("Information");
		error = new JButton("Error");
		warning = new JButton("Warning");
		question = new JButton("Question");

		// -------------
		// add listeners
		// -------------

		ActionListener observer = new MyButtonListener();

		plain.addActionListener(observer);
		information.addActionListener(observer);
		error.addActionListener(observer);
		warning.addActionListener(observer);
		question.addActionListener(observer);

		// ------------------
		// arrange components
		// ------------------

		// put components in a panel

		JPanel buttonPanel = new JPanel();
		buttonPanel.add(plain);
		buttonPanel.add(information);
		buttonPanel.add(error);
		buttonPanel.add(warning);
		buttonPanel.add(question);
		buttonPanel.setBorder(BorderFactory.createEmptyBorder(40, 20, 40, 20));

		// create a container for this (extended) JFrame's content pane

		Container c = this.getContentPane();

		// add the panel to the container

		c.add(buttonPanel, "Center");
	}

	class MyButtonListener implements ActionListener {
		public void actionPerformed(ActionEvent ae) {
			Object[] options = { "Yes, please", "No, thanks",
					"No eggs, no ham!" };
			Object source = ae.getSource();
			if (source == plain)
				JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
						"Let's take a look at the eggs!", "Plain",
						JOptionPane.PLAIN_MESSAGE);
			if (source == information)
				JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
						"The eggs are green!", "Information",
						JOptionPane.INFORMATION_MESSAGE);
			if (source == error) {
				Toolkit.getDefaultToolkit().beep();
				JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
						"Eggs aren't supposed to be green!", "Error",
						JOptionPane.ERROR_MESSAGE);
			}
			if (source == warning)
				JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
						"Do not eat the eggs!", "Warning",
						JOptionPane.WARNING_MESSAGE);
			if (source == question) {
				int n = JOptionPane
						.showOptionDialog(DemoMessageBoxFrame2.this,
								"Would you like some green eggs to go "
										+ "with that ham?", "A Silly Question",
								JOptionPane.YES_NO_CANCEL_OPTION,
								JOptionPane.QUESTION_MESSAGE, null, options,
								options[2]);
				if (n == JOptionPane.YES_OPTION)
					JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
							"Here you go, but be careful!", "Warning",
							JOptionPane.WARNING_MESSAGE);
				else if (n == JOptionPane.NO_OPTION)
					JOptionPane.showMessageDialog(DemoMessageBoxFrame2.this,
							"OK, just ham then!", "Information",
							JOptionPane.INFORMATION_MESSAGE);
				else
					JOptionPane.showConfirmDialog(DemoMessageBoxFrame2.this,
							"Should I eat the ham then?", "Question",
							JOptionPane.YES_NO_OPTION,
							JOptionPane.QUESTION_MESSAGE);
			}

		}
	}
}