package exampleSetWidgets;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * <code>DemoToggleCase</code> is similar to <code>DemoBasicV4</code>. In
 * this demo, we set up a keyboard mnemonic for the button <center><img src =
 * "img/DemoButtonMnemonic-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoButtonMnemonic.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoToggleCaseV1 {
	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}

	private static void createAndShowGUI() {
		JFrame frame = new DemoToggleCaseFrame();
		frame.setTitle("DemoToggleCase");
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}
}

class DemoToggleCaseFrame extends JFrame {
	private JLabel sampleLabel;
	private JButton toggleButton;
	private String SAMPLE_PHRASE = "sample label";

	public DemoToggleCaseFrame() {
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		// Step 1: Create and Configure Components
		sampleLabel = new JLabel(SAMPLE_PHRASE);
		sampleLabel.setPreferredSize(new Dimension(250, 100));
		sampleLabel.setFont(new Font("sanserif", Font.PLAIN, 16));

		toggleButton = new JButton("toggle case");
		toggleButton.setMnemonic(KeyEvent.VK_T);

		toggleButton.setFont(new Font("sanserif", Font.PLAIN, 16));

		// Step 2: Register Listeners
		toggleButton.addActionListener(new MyButtonListener());

		// Step 3: Arrange components in contentPane
		JPanel panel = new JPanel();
		panel.add(sampleLabel);
		panel.add(toggleButton);
		setContentPane(panel);
	}

	class MyButtonListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			System.out.println("toggleButton generated ActionEvent.");
			if (isLowerCase(sampleLabel.getText()))
				sampleLabel.setText(sampleLabel.getText().toUpperCase());
			else
				sampleLabel.setText(sampleLabel.getText().toLowerCase());
		}

		public boolean isLowerCase(String s) {
			return s.equals(s.toLowerCase());
		}

	}
}
