package exampleSetWidgets;
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * <code>DemoToggleCase</code> is similar to <code>DemoBasicV4</code>. In
 * this demo, we set up a keyboard mnemonic for the button <center><img src =
 * "img/DemoButtonMnemonic-1.gif"></center>
 * <p>
 * 
 * @see <a href="../DemoButtonMnemonic.java">source code</a>
 * @author M. Baljko, 2004
 */
public class DemoToggleCaseV2 {
	public static void main(String[] args) {
		boolean DO_CORRECT_WAY = true;

		if (DO_CORRECT_WAY) {
			javax.swing.SwingUtilities.invokeLater(new Runnable() {
				public void run() {
					createAndShowGUI();
				}
			});
		} else {
			JFrame frame = new DemoToggleCaseFrame();
			frame.setTitle("DemoToggleCase");
			frame.pack();
			frame.setVisible(true); // alternative: frame.show()
		}
	}

	private static void createAndShowGUI() {
		JFrame frame = new DemoToggleCaseFrame();
		frame.setTitle("DemoToggleCase");
		frame.pack();
		frame.setVisible(true); // alternative: frame.show()
	}
}

class DemoToggleCaseFrame2 extends JFrame {
	private JLabel sampleLabel;
	private JButton toggleButton;
	private String SAMPLE_PHRASE = "sample label";

	public DemoToggleCaseFrame2() {
		System.out.println("Is on EVT? (within constructor): "
				+ SwingUtilities.isEventDispatchThread());

		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		// Step 1: Create and Configure Components
		sampleLabel = new JLabel(SAMPLE_PHRASE);
		sampleLabel.setPreferredSize(new Dimension(250, 100));
		sampleLabel.setFont(new Font("sanserif", Font.PLAIN, 16));

		toggleButton = new JButton("toggle case");
		toggleButton.setMnemonic(KeyEvent.VK_P);

		toggleButton.setFont(new Font("sanserif", Font.PLAIN, 16));

		// Step 2: Register Listeners
		toggleButton.addActionListener(new DemoToggleCaseActionListener());

		// Step 3: Arrange components in contentPane
		JPanel panel = new JPanel();
		panel.add(sampleLabel);
		panel.add(toggleButton);
		setContentPane(panel);
	}

	class DemoToggleCaseActionListener implements ActionListener {

		public void actionPerformed(ActionEvent ae) {
			System.out.println(Thread.currentThread().getName());
			System.out.println("Is on EVT? (within actionPerformed): "
					+ SwingUtilities.isEventDispatchThread());
			if (ae.getSource() == toggleButton) {
				System.out.println("toggleButton generated ActionEvent");
				if (isLowerCase(sampleLabel.getText()))
					sampleLabel.setText(sampleLabel.getText().toUpperCase());
				else
					sampleLabel.setText(sampleLabel.getText().toLowerCase());
			}
		}

		public boolean isLowerCase(String s) {
			return s.equals(s.toLowerCase());
		}

	}
}
